@@ -908,15 +908,10 @@ html_painter_alloc_font (HTMLPainter *painter,
 	}
 
 	if (!desc || !pango_font_description_get_family (desc)) {
-		GtkStyleContext *style_context;
-		const PangoFontDescription *font_desc;
-
 		if (desc)
 			pango_font_description_free (desc);
 
-		style_context = gtk_widget_get_style_context (painter->widget);
-		font_desc = gtk_style_context_get_font (style_context, GTK_STATE_FLAG_NORMAL);
-		desc = pango_font_description_copy (font_desc);
+		desc = pango_font_description_copy (gtk_widget_get_style (painter->widget)->font_desc);
 	}
 
 	if (points)
@@ -1010,14 +1005,14 @@ guint
 html_painter_get_page_width (HTMLPainter *painter,
                              HTMLEngine *e)
 {
-	return (* HP_CLASS (painter)->get_page_width) (painter, e);
+	return	(* HP_CLASS (painter)->get_page_width) (painter, e);
 }
 
 guint
 html_painter_get_page_height (HTMLPainter *painter,
                               HTMLEngine *e)
 {
-	return (* HP_CLASS (painter)->get_page_height) (painter, e);
+	return	(* HP_CLASS (painter)->get_page_height) (painter, e);
 }
 
 /**
